pub const fn ticket_level_for_status(status: ChunkStatus) -> ChunkTicketLevelExpand description
Returns the ticket level that permits a chunk to reach at least status.
This is derived from the full-chunk dependency pyramid so request tickets use the same propagation rules as player tickets.