pub(crate) struct TimedChunkTickets {
tickets: Vec<TimedChunkTicket>,
}Expand description
Timed chunk tickets owned by vanilla gameplay systems.
Fields
tickets: Vec<TimedChunkTicket>Implementations
Sourceimpl TimedChunkTickets
impl TimedChunkTickets
Sourcepub(crate) fn from_persistent(persistent: PersistentChunkTickets) -> Self
pub(crate) fn from_persistent(persistent: PersistentChunkTickets) -> Self
Restores timed tickets from persistent saved data.
Sourcepub(crate) fn to_persistent(&self) -> PersistentChunkTickets
pub(crate) fn to_persistent(&self) -> PersistentChunkTickets
Converts active timed tickets to persistent saved data.
Sourcepub(crate) fn activate_all(&self, ticket_manager: &mut ChunkTicketManager)
pub(crate) fn activate_all(&self, ticket_manager: &mut ChunkTicketManager)
Inserts restored timed ticket sources into the active ticket manager.
Sourcepub(crate) fn add_portal_ticket(&mut self, pos: ChunkPos) -> Option<ChunkTicket>
pub(crate) fn add_portal_ticket(&mut self, pos: ChunkPos) -> Option<ChunkTicket>
Adds or refreshes vanilla’s portal ticket.
Sourcepub(crate) fn add_ender_pearl_ticket(
&mut self,
pos: ChunkPos,
) -> Option<ChunkTicket>
pub(crate) fn add_ender_pearl_ticket( &mut self, pos: ChunkPos, ) -> Option<ChunkTicket>
Adds or refreshes vanilla’s in-flight ender pearl ticket.
Sourcepub(crate) fn tick(
&mut self,
can_expire: impl FnMut(ChunkPos) -> bool,
) -> Vec<(ChunkPos, ChunkTicket)>
pub(crate) fn tick( &mut self, can_expire: impl FnMut(ChunkPos) -> bool, ) -> Vec<(ChunkPos, ChunkTicket)>
Decrements timed tickets and returns sources that expired this tick.
fn add_or_reset( &mut self, kind: TimedChunkTicketKind, pos: ChunkPos, ticket: ChunkTicket, ticks_left: i64, ) -> Option<ChunkTicket>
fn add_loaded_persistent_ticket(&mut self, persistent: PersistentChunkTicket)
fn add_loaded_portal_ticket(&mut self, pos: ChunkPos, ticks_left: i64)